/*******************************************************************************
 * Copyright 2019 Graz University of Technology
 * MOA ZS has been developed in a cooperation between EGIZ
 * and Graz University of Technology.
 * Licensed under the EUPL, Version 1.2 or - as soon they will be approved by
 * the European Commission - subsequent versions of the EUPL (the "Licence");
 * You may not use this work except in compliance with the Licence.
 * You may obtain a copy of the Licence at:
 * https://joinup.ec.europa.eu/news/understanding-eupl-v12
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the Licence is distributed on an "AS IS" basis,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the Licence for the specific language governing permissions and
 * limitations under the Licence.
 *
 * This product combines work with different licenses. See the "NOTICE" text
 * file for details on the various modules and licenses.
 * The "NOTICE" text file is part of the distribution. Any derivative works
 * that you distribute must include a readable copy of the "NOTICE" text file.
 *******************************************************************************/
package at.gv.egiz.moazs.util;

import org.apache.cxf.Bus;
import org.apache.cxf.interceptor.Interceptor;
import org.apache.cxf.jaxws.EndpointImpl;
import org.apache.cxf.message.Message;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Component;
import javax.xml.ws.Endpoint;

import javax.xml.ws.Service;

/**
 * @author Christof Rabensteiner
 *
 */
@Component
public class EndpointFactory {

    private final Bus bus;

    @Autowired
    public EndpointFactory(Bus bus) {
        this.bus = bus;
    }

    public Endpoint create(Object implementor, Service service, String route) {
        return create(implementor, service, route, null);
    }

    public Endpoint create(Object implementor, Service service, String route, Interceptor<Message> interceptor) {
        EndpointImpl endpoint = new EndpointImpl(bus, implementor);
        endpoint.setAddress(route);
        endpoint.setServiceName(service.getServiceName());
        endpoint.setWsdlLocation(service.getWSDLDocumentLocation().toString());
        endpoint.publish();

        if (interceptor != null) {
            endpoint.getInInterceptors().add(interceptor);
        }

        return endpoint;
    }

}
